@@ -28,9 +28,9 @@ def Busqueda(symbolo):
   for c_element in DatosList:
     if c_element[0] == symbolo:
       if isinstance(c_element[1],float):#Si tenemos un numero
-          return sympy.symbols(str(c_element[1]))
+          return sympy.symbols("("+str(c_element[1])+")")
       elif isinstance(c_element[1],int):#Si tenemos un float
-          return sympy.symbols(str(c_element[1]))
+          return sympy.symbols("("+str(c_element[1])+")")
       elif c_element[1] != None:#Si tenemos una expresión
           return c_element[1]
       else:
